# UpdateProcessJobDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**process_id** | **str** |  | [optional] 
**project_id** | **str** |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**config** | **object** |  | [optional] 
**analysis_job_id** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

